package com.hzya.frame.plugin.cbs8.service.impl;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.cbs8.dto.req.PayResultRequestDTO;
import com.hzya.frame.cbs8.dto.res.PayResponseDTO;
import com.hzya.frame.cbs8.dto.res.PayResultResDTO;
import com.hzya.frame.cbs8.service.ICbs8Service;
import com.hzya.frame.cbs8.util.CBSUtil;
import com.hzya.frame.cbs8.util.PayState;
import com.hzya.frame.plugin.cbs8.plugin.PayApplyPluginInitializer;
import com.hzya.frame.plugin.cbs8.service.ICbsPluginService;
import com.hzya.frame.seeyon.cbs8.entity.CbsLogEntity;
import com.hzya.frame.seeyon.cbs8.entity.PaymentEntity;
import com.hzya.frame.seeyon.cbs8.service.ICbsLogService;
import com.hzya.frame.seeyon.cbs8.service.IPaymentService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description
 * @Author xiangerlin
 * @Date 2024/6/17 08:46
 **/
public class CbsPluginServiceImpl implements ICbsPluginService {

    Logger logger = LoggerFactory.getLogger(CbsPluginServiceImpl.class);
    @Autowired
    private ICbs8Service cbs8Service;
    @Autowired
    private IPaymentService paymentService;
    @Autowired
    private ICbsLogService cbsLogService;

    /**
     * 支付申请
     *
     * @param requestJson
     */
    @Override
    public void applyPay(JSONObject requestJson) throws Exception{
        //查询待支付的列表
        PaymentEntity paymentEntity = new PaymentEntity();
        paymentEntity.setDataSourceCode("");
        //List<PaymentEntity> paymentList = paymentService.queryUnpaid(paymentEntity);
        List<PaymentEntity> paymentList = new ArrayList<>();
        paymentEntity.setReferenceNum("CL202406140001");
        paymentEntity.setPayAccount("655905707410000");
        paymentEntity.setPayBankName("");
        paymentEntity.setAmount("99");
        paymentEntity.setRevAccount("123456778");
        paymentEntity.setRevBankName("中国工商银行总行清算中心");
        paymentEntity.setRevBankType("ICB");
        paymentEntity.setRevAccountName("测试账户");
        paymentEntity.setCnapsCode("102100099996");
        paymentEntity.setPurpose("测试用途");
        paymentEntity.setBusType("202");
        paymentEntity.setCurrency("10");
        paymentEntity.setPurpose("测试用途");
        paymentList.add(paymentEntity);
        if (CollectionUtils.isNotEmpty(paymentList)){
            for (PaymentEntity pay : paymentList) {
                //调用支付申请接口
                PayResponseDTO payResponseDTO = cbs8Service.payApply(pay);
                //4、更新OA表单
                paymentService.updatePayState(pay);
                //5、记录操作日志
                cbsLogService.saveLog(new CbsLogEntity());
            }
        }
    }

    /**
     * 查询支付申请的交易结果
     *
     * @param requestJson
     * @throws Exception
     */
    @Override
    public void queryResult(JSONObject requestJson) throws Exception {
        CbsLogEntity cbsLogEntity = new CbsLogEntity();
        // 1、查询支付中的日志
        List<CbsLogEntity> inPayList = cbsLogService.queryInPayment(cbsLogEntity);
        if (CollectionUtils.isNotEmpty(inPayList)){
            for (CbsLogEntity entity : inPayList) {
                try {
                    List<PayResultResDTO> payResultResList = cbs8Service.queryPayResult(new PayResultRequestDTO(entity.getBill_code()));
                    if (CollectionUtils.isNotEmpty(payResultResList)){
                        PayResultResDTO payResultResDTO = payResultResList.get(0);
                        //支付申请状态
                        String status = payResultResDTO.getStatus();
                        //支付状态
                        String pay_status = payResultResDTO.getPayStatus();
                        //不等于支付中的时候 更新支付状态
                        if (!PayState.p.getType().equals(pay_status)){
                            //如果支付状态为空，保存支付申请状态，如果支付状态不为空，则保存支付状态
                            PaymentEntity paymentEntity = new PaymentEntity();
                            paymentEntity.setOaId(entity.getOa_id());
                            List<PaymentEntity> paymentList = paymentService.query(paymentEntity);
                            if (CollectionUtils.isNotEmpty(paymentList)){
                                paymentEntity = paymentList.get(0);
                                if (StrUtil.isEmpty(pay_status)) {
                                    //支付申请状态 支付状态和支付申请状态用一个
                                    paymentEntity.setPayResult(PayState.payStateGetValue(status));
                                } else {
                                    //支付状态 支付状态和支付申请状态用一个
                                    paymentEntity.setPayResult(PayState.payStateGetValue(pay_status));
                                }
                                if (StrUtil.isNotEmpty(pay_status) && pay_status.equals(PayState.g.getType())) {
                                    //支付时间
                                    paymentEntity.setPayDate(CBSUtil.convertTimestampToString(payResultResDTO.getPayDate()));
                                }
                                //更新视图单据状态
                                paymentService.updatePayState(paymentEntity);
                                //更新日志表状态
                                entity.setPay_state(paymentEntity.getPayResult());
                                entity.setApply_state(PayState.payStateGetValue(status));
                                cbsLogService.update(entity);
                            }
                        }
                    }
                }catch (Exception e){
                 e.printStackTrace();
                 logger.error("查询交易结果出错",e);
                }
            }
        }
    }
}
